import AllValidator from './AllValidator';
/**
 * Validator for Number parameters, which includes multiple Number validation methods.
 */
declare class NumberValidator<O extends boolean = false> extends AllValidator<number, O, false> {
    #private;
    output: number;
    constructor();
    optional(): NumberValidator<true>;
    nullable(): NumberValidator<O>;
    /**
     * Set minimum value of a number.
     * Returns true if number >= min.
     * @param {number} min minimum value
     * @returns {NumberValidator} NumberValidator
     */
    min(min: number): this;
    /**
     * Set maximum value of a number.
     * Returns true if number <= max.
     * @param {number} max maximum value
     * @returns {NumberValidator} NumberValidator
     */
    max(max: number): this;
    /**
     * Check if a number is an integer.
     * Returns true if number is an integer.
     * @returns {NumberValidator} NumberValidator
     */
    int(): this;
    /**
     * Check if number is positive.
     * Returns true if number >= 0.
     * @returns {NumberValidator} NumberValidator
     */
    positive(): this;
    /**
     * Check if number is negative.
     * Returns true if number <= 0.
     * @returns {NumberValidator} NumberValidator
     */
    negative(): this;
    /**
     * Check if number is a positive integer.
     * Returns true if the number is a positive integer.
     * @returns {NumberValidator} NumberValidator
     */
    id(): this;
    /**
     * Set fixed length of a float number.
     * Returns true if the fixed length equals.
     * @param {number} len fixed length
     * @returns {NumberValidator} NumberValidator
     */
    toFixed(len: number): this;
    /**
     * Check if number is one of the array elements.
     * Returns true if the number is in the array.
     * @param {number[]} arr number set
     * @returns {NumberValidator} NumberValidator
     */
    oneof(arr: number[]): this;
    test(p?: any): boolean;
}
export default NumberValidator;
